==> nautobot-evpn-0.1.4.tar.gz: nautobot-evpn-0.1.4/nautobot_evpn/models.py <==
from django.db import models, transaction

from nautobot.core.models import BaseModel
from nautobot.dcim.models import Device, Interface
from nautobot.ipam.models import IPAddress, VLAN, VRF
from nautobot.utilities.querysets import RestrictedQuerySet


class VLANVRF(BaseModel):
    vlan = models.OneToOneField(
        VLAN,
        blank=False,
        null=False,
        on_delete=models.CASCADE,
    )
    vrf = models.OneToOneField(
        VRF,
        blank=False,
        null=False,
        on_delete=models.CASCADE,
    )


class EthernetSegment(BaseModel):
    segment_id = models.IntegerField(unique=True)
    name = models.CharField(max_length=256)

    csv_headers = ["segment_id", "name"]

    objects = RestrictedQuerySet.as_manager()

    @property
    def members(self):
        return EthernetSegmentMembership.objects.filter(segment=self).values_list("interface", flat=True)

    def __str__(self):
        return "{} ({})".format(self.name, self.segment_id)


class EthernetSegmentMembership(BaseModel):
    segment = models.ForeignKey(
        EthernetSegment,
        on_delete=models.CASCADE
    )
    interface = models.OneToOneField(
        Interface,
        on_delete=models.CASCADE
    )

    csv_headers = ["segment", "interface"]

    objects = RestrictedQuerySet.as_manager()


class VLANVRFList(BaseModel):
    vlan = models.OneToOneField(
        VLAN,
        blank=False,
        null=False,
        on_delete=models.CASCADE,
    )
    vrf = models.ForeignKey(
        VRF,
        blank=False,
        null=False,
        on_delete=models.CASCADE,
    )


class AnycastIP(BaseModel):
    vlan = models.ForeignKey(
        VLAN,
        blank=False,
        null=False,
        on_delete=models.CASCADE,
    )
    ip = models.OneToOneField(
        IPAddress,
        blank=False,
        null=False,
        on_delete=models.CASCADE,
    )


class AnycastDummyIP(BaseModel):
    vlan = models.ForeignKey(
        VLAN,
        blank=False,
        null=False,
        on_delete=models.CASCADE,
    )
    ip = models.OneToOneField(
        IPAddress,
        blank=False,
        null=False,
        on_delete=models.CASCADE,
    )

==> nautobot-evpn-0.1.5.tar.gz: nautobot-evpn-0.1.5/nautobot_evpn/models.py <==
from django.db import models, transaction

from nautobot.core.models.generics import PrimaryModel
from nautobot.dcim.models import Device, Interface
from nautobot.ipam.models import IPAddress, VLAN, VRF
from nautobot.utilities.querysets import RestrictedQuerySet


class VRFPrimaryVLAN(PrimaryModel):
    vlan = models.OneToOneField(
        VLAN,
        blank=False,
        null=False,
        on_delete=models.CASCADE,
    )
    vrf = models.OneToOneField(
        VRF,
        blank=False,
        null=False,
        on_delete=models.CASCADE,
    )

    class Meta:
        verbose_name = "VRF Primary VLAN"
        verbose_name_plural = "VRF Primary VLANs"

    def __str__(self):
        return f'{self.vlan} in {self.vrf}'


class EthernetSegment(PrimaryModel):
    segment_id = models.IntegerField(unique=True)
    name = models.CharField(max_length=256)

    csv_headers = ["segment_id", "name"]

    objects = RestrictedQuerySet.as_manager()

    @property
    def members(self):
        return EthernetSegmentMembership.objects.filter(segment=self).values_list("interface", flat=True)

    class Meta:
        verbose_name = "Ethernet Segment"
        verbose_name_plural = "Ethernet Segments"

    def __str__(self):
        return "{} ({})".format(self.name, self.segment_id)


class EthernetSegmentMembership(PrimaryModel):
    segment = models.ForeignKey(
        EthernetSegment,
        on_delete=models.CASCADE
    )
    interface = models.OneToOneField(
        Interface,
        on_delete=models.CASCADE
    )

    csv_headers = ["segment", "interface"]

    objects = RestrictedQuerySet.as_manager()

    class Meta:
        verbose_name = "Ethernet Segment Membership"
        verbose_name_plural = "Ethernet Segment Memberships"

    def __str__(self):
        return f'{self.interface} in {self.segment}'


class VLANVRFList(PrimaryModel):
    vlan = models.OneToOneField(
        VLAN,
        blank=False,
        null=False,
        on_delete=models.CASCADE,
    )
    vrf = models.ForeignKey(
        VRF,
        blank=False,
        null=False,
        on_delete=models.CASCADE,
    )

    class Meta:
        verbose_name = "VLAN-To-VRF-Attachment"
        verbose_name_plural = "VLAN-To-VRF-Attachments"

    def __str__(self):
        return f'{self.vrf} at {self.vlan}'


class AnycastIP(PrimaryModel):
    vlan = models.ForeignKey(
        VLAN,
        blank=False,
        null=False,
        on_delete=models.CASCADE,
    )
    ip = models.OneToOneField(
        IPAddress,
        blank=False,
        null=False,
        on_delete=models.CASCADE,
    )

    def __str__(self):
        return f'{self.ip} at {self.vlan}'


class AnycastDummyIP(PrimaryModel):
    vlan = models.ForeignKey(
        VLAN,
        blank=False,
        null=False,
        on_delete=models.CASCADE,
    )
    ip = models.OneToOneField(
        IPAddress,
        blank=False,
        null=False,
        on_delete=models.CASCADE,
    )

    def __str__(self):
        return f'{self.ip} at {self.vlan}'
